Count
=====

.. currentmodule:: pykeen.metrics.ranking

.. autoclass:: Count
   :show-inheritance:

   .. rubric:: Attributes Summary

   .. autosummary::

      ~Count.increasing
      ~Count.name
      ~Count.synonyms
      ~Count.value_range

   .. rubric:: Methods Summary

   .. autosummary::

      ~Count.__call__

   .. rubric:: Attributes Documentation

   .. autoattribute:: increasing
   .. autoattribute:: name
   .. autoattribute:: synonyms
   .. autoattribute:: value_range

   .. rubric:: Methods Documentation

   .. automethod:: __call__
